@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IAddressBook_VERSION = "4.1.62132"
+IAddressBook_VERSION = "4.1.64823"
 
 class IAddressBook(BaseEndpoint):
     def __init__(self, apiKey, url ,containerUid ):
@@ -32,6 +32,14 @@ class IAddressBook(BaseEndpoint):
         self.containerUid_ = containerUid
         self.base = self.base.replace('{containerUid}',containerUid)
 
+    def getVersion (self):
+        postUri = "/_version";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        return self.handleResult__(serder.LONG, response)
     def filteredChangesetById (self, since , arg1 ):
         postUri = "/_filteredChangesetById";
         __data__ = None
@@ -48,6 +56,163 @@ class IAddressBook(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
+    def itemChangelog (self, uid , arg1 ):
+        postUri = "/{uid}/_itemchangelog";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        __data__ = serder.LONG.encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {    };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
+        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
+        return self.handleResult__(__ItemChangelogSerDer__(), response)
+    def changeset (self, since ):
+        postUri = "/_changeset";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  'since': since   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
+    def changesetById (self, since ):
+        postUri = "/_changesetById";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  'since': since   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
+    def containerChangelog (self, arg0 ):
+        postUri = "/_changelog";
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.LONG.encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
+        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
+        return self.handleResult__(__ContainerChangelogSerDer__(), response)
+    def allIds (self, filter , knownContainerVersion , limit , offset ):
+        postUri = "/_itemIds";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  'filter': filter  , 'knownContainerVersion': knownContainerVersion  , 'limit': limit  , 'offset': offset   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        from netbluemind.core.api.ListResult import ListResult
+        from netbluemind.core.api.ListResult import __ListResultSerDer__
+        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
+    def multipleGetById (self, arg0 ):
+        postUri = "/_mgetById";
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VCardSerDer__())), response)
+    def getCompleteById (self, id ):
+        postUri = "/{id}/completeById";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}",id);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__VCardSerDer__()), response)
+    def multipleDeleteById (self, arg0 ):
+        postUri = "/_multipleDelete";
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
+    def updateById (self, id , arg1 ):
+        postUri = "/id/{id}";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}",id);
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        __data__ = __VCardSerDer__().encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {    };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        from netbluemind.core.container.api.Ack import Ack
+        from netbluemind.core.container.api.Ack import __AckSerDer__
+        return self.handleResult__(__AckSerDer__(), response)
+    def deleteById (self, id ):
+        postUri = "/id/{id}";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}",id);
+        queryParams = {   };
+
+        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
+    def createById (self, id , arg1 ):
+        postUri = "/id/{id}";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}",id);
+        from netbluemind.addressbook.api.VCard import VCard
+        from netbluemind.addressbook.api.VCard import __VCardSerDer__
+        __data__ = __VCardSerDer__().encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {    };
+
+        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        from netbluemind.core.container.api.Ack import Ack
+        from netbluemind.core.container.api.Ack import __AckSerDer__
+        return self.handleResult__(__AckSerDer__(), response)
+    def count (self, arg0 ):
+        postUri = "/_count";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
+        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
+        __data__ = __ItemFlagFilterSerDer__().encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        from netbluemind.core.container.api.Count import Count
+        from netbluemind.core.container.api.Count import __CountSerDer__
+        return self.handleResult__(__CountSerDer__(), response)
+    def sortedIds (self, arg0 ):
+        postUri = "/_sorted";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
+        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
+        __data__ = __SortDescriptorSerDer__().encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
+        return self.handleResult__(serder.ListSerDer(serder.LONG), response)
     def getPhoto (self, uid ):
         postUri = "/{uid}/photo";
         __data__ = None
@@ -110,26 +275,6 @@ class IAddressBook(BaseEndpoint):
 
         response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def changeset (self, since ):
-        postUri = "/_changeset";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  'since': since   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
-    def changesetById (self, since ):
-        postUri = "/_changesetById";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  'since': since   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
     def search (self, query ):
         postUri = "/_search";
         __data__ = None
@@ -172,27 +317,6 @@ class IAddressBook(BaseEndpoint):
 
         response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def getCompleteById (self, id ):
-        postUri = "/id/{id}";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}",id);
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__VCardSerDer__()), response)
-    def getVersion (self):
-        postUri = "/_version";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        return self.handleResult__(serder.LONG, response)
     def move (self, uids , destContainerUid ):
         postUri = "/_move/{destContainerUid}";
         __data__ = None
@@ -231,34 +355,6 @@ class IAddressBook(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__VCardInfoSerDer__()), response)
-    def updateWithItem (self, cardItem ):
-        postUri = "/_updateWithItem";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        __data__ = __ItemValueSerDer__(__VCardSerDer__()).encode(cardItem)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
-    def count (self, arg0 ):
-        postUri = "/_count";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
-        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
-        __data__ = __ItemFlagFilterSerDer__().encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        from netbluemind.core.container.api.Count import Count
-        from netbluemind.core.container.api.Count import __CountSerDer__
-        return self.handleResult__(__CountSerDer__(), response)
     def touch (self, uid ):
         postUri = "/{uid}/_touch";
         __data__ = None
@@ -269,18 +365,6 @@ class IAddressBook(BaseEndpoint):
 
         response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def sortedIds (self, sorted ):
-        postUri = "/_sorted";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
-        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
-        __data__ = __SortDescriptorSerDer__().encode(sorted)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        return self.handleResult__(serder.ListSerDer(serder.LONG), response)
     def sync (self, since , changes ):
         postUri = "/_sync";
         __data__ = None
@@ -295,29 +379,6 @@ class IAddressBook(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
-    def itemChangelog (self, uid , arg1 ):
-        postUri = "/{uid}/_itemchangelog";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        __data__ = serder.LONG.encode(arg1)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {    };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
-        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
-        return self.handleResult__(__ItemChangelogSerDer__(), response)
-    def multipleDeleteById (self, arg0 ):
-        postUri = "/_multipleDelete";
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
     def getIcon (self, uid ):
         postUri = "/{uid}/icon";
         __data__ = None
@@ -327,21 +388,6 @@ class IAddressBook(BaseEndpoint):
 
         response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
         return self.handleResult__(serder.ByteArraySerDer, response)
-    def updateById (self, id , value ):
-        postUri = "/id/{id}";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}",id);
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        __data__ = __VCardSerDer__().encode(value)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {    };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        from netbluemind.core.container.api.Ack import Ack
-        from netbluemind.core.container.api.Ack import __AckSerDer__
-        return self.handleResult__(__AckSerDer__(), response)
     def getComplete (self, uid ):
         postUri = "/{uid}/complete";
         __data__ = None
@@ -355,46 +401,6 @@ class IAddressBook(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__VCardSerDer__()), response)
-    def multipleGetById (self, ids ):
-        postUri = "/_mgetById";
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(ids)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VCardSerDer__())), response)
-    def createWithItem (self, cardItem ):
-        postUri = "/_createWithItem";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        __data__ = __ItemValueSerDer__(__VCardSerDer__()).encode(cardItem)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
-    def containerChangelog (self, arg0 ):
-        postUri = "/_changelog";
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.LONG.encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
-        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
-        return self.handleResult__(__ContainerChangelogSerDer__(), response)
     def setPhoto (self, uid , photo ):
         postUri = "/{uid}/photo";
         __data__ = None
@@ -406,15 +412,6 @@ class IAddressBook(BaseEndpoint):
 
         response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def deleteById (self, id ):
-        postUri = "/id/{id}";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}",id);
-        queryParams = {   };
-
-        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
     def reset (self):
         postUri = "/_reset";
         __data__ = None
@@ -423,28 +420,3 @@ class IAddressBook(BaseEndpoint):
 
         response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def createById (self, id , value ):
-        postUri = "/id/{id}";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}",id);
-        from netbluemind.addressbook.api.VCard import VCard
-        from netbluemind.addressbook.api.VCard import __VCardSerDer__
-        __data__ = __VCardSerDer__().encode(value)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {    };
-
-        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        from netbluemind.core.container.api.Ack import Ack
-        from netbluemind.core.container.api.Ack import __AckSerDer__
-        return self.handleResult__(__AckSerDer__(), response)
-    def allIds (self, filter , knownContainerVersion , limit , offset ):
-        postUri = "/_itemIds";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  'filter': filter  , 'knownContainerVersion': knownContainerVersion  , 'limit': limit  , 'offset': offset   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IAddressBook_VERSION}, data = __encoded__);
-        from netbluemind.core.api.ListResult import ListResult
-        from netbluemind.core.api.ListResult import __ListResultSerDer__
-        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
