@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IBaseMailboxFolders_VERSION = "4.1.62132"
+IBaseMailboxFolders_VERSION = "4.1.64823"
 
 class IBaseMailboxFolders(BaseEndpoint):
     def __init__(self, apiKey, url ):
@@ -30,18 +30,6 @@ class IBaseMailboxFolders(BaseEndpoint):
         self.apiKey = apiKey
         self.base = url +''
 
-    def all (self):
-        postUri = "/_all";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IBaseMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
-        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__MailboxFolderSerDer__())), response)
     def getVersion (self):
         postUri = "/_version";
         __data__ = None
@@ -66,19 +54,6 @@ class IBaseMailboxFolders(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
-    def byName (self, name ):
-        postUri = "/byName/{name}";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{name}",name);
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IBaseMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
-        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
     def itemChangelog (self, uid , arg1 ):
         postUri = "/{uid}/_itemchangelog";
         __data__ = None
@@ -102,6 +77,63 @@ class IBaseMailboxFolders(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
+    def changesetById (self, since ):
+        postUri = "/_changesetById";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  'since': since   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IBaseMailboxFolders_VERSION}, data = __encoded__);
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
+    def containerChangelog (self, arg0 ):
+        postUri = "/_changelog";
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.LONG.encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IBaseMailboxFolders_VERSION}, data = __encoded__);
+        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
+        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
+        return self.handleResult__(__ContainerChangelogSerDer__(), response)
+    def allIds (self, filter , knownContainerVersion , limit , offset ):
+        postUri = "/_itemIds";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  'filter': filter  , 'knownContainerVersion': knownContainerVersion  , 'limit': limit  , 'offset': offset   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IBaseMailboxFolders_VERSION}, data = __encoded__);
+        from netbluemind.core.api.ListResult import ListResult
+        from netbluemind.core.api.ListResult import __ListResultSerDer__
+        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
+    def all (self):
+        postUri = "/_all";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IBaseMailboxFolders_VERSION}, data = __encoded__);
+        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
+        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__MailboxFolderSerDer__())), response)
+    def byName (self, name ):
+        postUri = "/byName/{name}";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{name}",name);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IBaseMailboxFolders_VERSION}, data = __encoded__);
+        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
+        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
     def getComplete (self, uid ):
         postUri = "/{uid}/complete";
         __data__ = None
@@ -115,42 +147,6 @@ class IBaseMailboxFolders(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
-    def changesetById (self, since ):
-        postUri = "/_changesetById";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  'since': since   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IBaseMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
-    def getMultipleById (self, ids ):
-        postUri = "/_mgetById";
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(ids)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IBaseMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
-        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__MailboxFolderSerDer__())), response)
-    def containerChangelog (self, arg0 ):
-        postUri = "/_changelog";
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.LONG.encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IBaseMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
-        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
-        return self.handleResult__(__ContainerChangelogSerDer__(), response)
     def root (self):
         postUri = "/_root";
         __data__ = None
@@ -177,13 +173,3 @@ class IBaseMailboxFolders(BaseEndpoint):
         from netbluemind.backend.mail.api.SearchResult import SearchResult
         from netbluemind.backend.mail.api.SearchResult import __SearchResultSerDer__
         return self.handleResult__(__SearchResultSerDer__(), response)
-    def allIds (self, filter , knownContainerVersion , limit , offset ):
-        postUri = "/_itemIds";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  'filter': filter  , 'knownContainerVersion': knownContainerVersion  , 'limit': limit  , 'offset': offset   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IBaseMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.core.api.ListResult import ListResult
-        from netbluemind.core.api.ListResult import __ListResultSerDer__
-        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
