@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IMailboxFolders_VERSION = "4.1.62132"
+IMailboxFolders_VERSION = "4.1.64823"
 
 class IMailboxFolders(BaseEndpoint):
     def __init__(self, apiKey, url ,partition ,mailboxRoot ):
@@ -34,21 +34,14 @@ class IMailboxFolders(BaseEndpoint):
         self.mailboxRoot_ = mailboxRoot
         self.base = self.base.replace('{mailboxRoot}',mailboxRoot)
 
-    def importItems (self, folderDestinationId , mailboxItems ):
-        postUri = "/importItems/{folderDestinationId}";
+    def getVersion (self):
+        postUri = "/_version";
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{folderDestinationId}",folderDestinationId);
-        from netbluemind.backend.mail.api.ImportMailboxItemSet import ImportMailboxItemSet
-        from netbluemind.backend.mail.api.ImportMailboxItemSet import __ImportMailboxItemSetSerDer__
-        __data__ = __ImportMailboxItemSetSerDer__().encode(mailboxItems)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {    };
+        queryParams = {  };
 
-        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.backend.mail.api.ImportMailboxItemsStatus import ImportMailboxItemsStatus
-        from netbluemind.backend.mail.api.ImportMailboxItemsStatus import __ImportMailboxItemsStatusSerDer__
-        return self.handleResult__(__ImportMailboxItemsStatusSerDer__(), response)
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
+        return self.handleResult__(serder.LONG, response)
     def filteredChangesetById (self, since , arg1 ):
         postUri = "/_filteredChangesetById";
         __data__ = None
@@ -65,19 +58,19 @@ class IMailboxFolders(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
-    def byName (self, name ):
-        postUri = "/byName/{name}";
+    def itemChangelog (self, uid , arg1 ):
+        postUri = "/{uid}/_itemchangelog";
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{name}",name);
-        queryParams = {   };
+        postUri = postUri.replace("{uid}",uid);
+        __data__ = serder.LONG.encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {    };
 
         response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
-        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
+        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
+        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
+        return self.handleResult__(__ItemChangelogSerDer__(), response)
     def changeset (self, since ):
         postUri = "/_changeset";
         __data__ = None
@@ -98,29 +91,66 @@ class IMailboxFolders(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
-    def getMultipleById (self, ids ):
-        postUri = "/_mgetById";
+    def containerChangelog (self, arg0 ):
+        postUri = "/_changelog";
         __data__ = None
         __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(ids)
+        __data__ = serder.LONG.encode(arg0)
         __encoded__ = json.dumps(__data__)
         queryParams = {   };
 
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
+        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
+        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
+        return self.handleResult__(__ContainerChangelogSerDer__(), response)
+    def allIds (self, filter , knownContainerVersion , limit , offset ):
+        postUri = "/_itemIds";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  'filter': filter  , 'knownContainerVersion': knownContainerVersion  , 'limit': limit  , 'offset': offset   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
+        from netbluemind.core.api.ListResult import ListResult
+        from netbluemind.core.api.ListResult import __ListResultSerDer__
+        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
+    def all (self):
+        postUri = "/_all";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
         from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
         from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__MailboxFolderSerDer__())), response)
-    def emptyFolder (self, id ):
-        postUri = "/empty/{id}";
+    def byName (self, name ):
+        postUri = "/byName/{name}";
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{id}",id);
+        postUri = postUri.replace("{name}",name);
         queryParams = {   };
 
-        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
+        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
+        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
+    def getComplete (self, uid ):
+        postUri = "/{uid}/complete";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
+        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
+        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
     def root (self):
         postUri = "/_root";
         __data__ = None
@@ -133,28 +163,6 @@ class IMailboxFolders(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
-    def getCompleteById (self, id ):
-        postUri = "/{id}/completeById";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}",id);
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
-        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
-    def removeMessages (self, id ):
-        postUri = "/removeMessages/{id}";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}",id);
-        queryParams = {   };
-
-        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
     def searchItems (self, query ):
         postUri = "/_search";
         __data__ = None
@@ -169,6 +177,66 @@ class IMailboxFolders(BaseEndpoint):
         from netbluemind.backend.mail.api.SearchResult import SearchResult
         from netbluemind.backend.mail.api.SearchResult import __SearchResultSerDer__
         return self.handleResult__(__SearchResultSerDer__(), response)
+    def multipleGetById (self, arg0 ):
+        postUri = "/_mgetById";
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
+        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
+        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__MailboxFolderSerDer__())), response)
+    def getCompleteById (self, id ):
+        postUri = "/{id}/completeById";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}",id);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
+        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
+        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
+    def importItems (self, folderDestinationId , mailboxItems ):
+        postUri = "/importItems/{folderDestinationId}";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{folderDestinationId}",folderDestinationId);
+        from netbluemind.backend.mail.api.ImportMailboxItemSet import ImportMailboxItemSet
+        from netbluemind.backend.mail.api.ImportMailboxItemSet import __ImportMailboxItemSetSerDer__
+        __data__ = __ImportMailboxItemSetSerDer__().encode(mailboxItems)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {    };
+
+        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
+        from netbluemind.backend.mail.api.ImportMailboxItemsStatus import ImportMailboxItemsStatus
+        from netbluemind.backend.mail.api.ImportMailboxItemsStatus import __ImportMailboxItemsStatusSerDer__
+        return self.handleResult__(__ImportMailboxItemsStatusSerDer__(), response)
+    def emptyFolder (self, id ):
+        postUri = "/empty/{id}";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}",id);
+        queryParams = {   };
+
+        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
+    def removeMessages (self, id ):
+        postUri = "/removeMessages/{id}";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}",id);
+        queryParams = {   };
+
+        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
     def markFolderAsRead (self, id ):
         postUri = "/markAsRead/{id}";
         __data__ = None
@@ -178,26 +246,6 @@ class IMailboxFolders(BaseEndpoint):
 
         response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def all (self):
-        postUri = "/_all";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
-        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__MailboxFolderSerDer__())), response)
-    def getVersion (self):
-        postUri = "/_version";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
-        return self.handleResult__(serder.LONG, response)
     def createBasic (self, value ):
         postUri = "";
         __data__ = None
@@ -227,19 +275,6 @@ class IMailboxFolders(BaseEndpoint):
         from netbluemind.core.container.model.ItemIdentifier import ItemIdentifier
         from netbluemind.core.container.model.ItemIdentifier import __ItemIdentifierSerDer__
         return self.handleResult__(__ItemIdentifierSerDer__(), response)
-    def itemChangelog (self, uid , arg1 ):
-        postUri = "/{uid}/_itemchangelog";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        __data__ = serder.LONG.encode(arg1)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {    };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
-        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
-        return self.handleResult__(__ItemChangelogSerDer__(), response)
     def updateById (self, id , value ):
         postUri = "/id/{id}";
         __data__ = None
@@ -255,31 +290,6 @@ class IMailboxFolders(BaseEndpoint):
         from netbluemind.core.container.api.Ack import Ack
         from netbluemind.core.container.api.Ack import __AckSerDer__
         return self.handleResult__(__AckSerDer__(), response)
-    def getComplete (self, uid ):
-        postUri = "/{uid}/complete";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
-        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)
-    def containerChangelog (self, arg0 ):
-        postUri = "/_changelog";
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.LONG.encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
-        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
-        return self.handleResult__(__ContainerChangelogSerDer__(), response)
     def deleteById (self, id ):
         postUri = "/id/{id}";
         __data__ = None
@@ -298,13 +308,3 @@ class IMailboxFolders(BaseEndpoint):
 
         response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def allIds (self, filter , knownContainerVersion , limit , offset ):
-        postUri = "/_itemIds";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  'filter': filter  , 'knownContainerVersion': knownContainerVersion  , 'limit': limit  , 'offset': offset   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolders_VERSION}, data = __encoded__);
-        from netbluemind.core.api.ListResult import ListResult
-        from netbluemind.core.api.ListResult import __ListResultSerDer__
-        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
