@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-ICalendar_VERSION = "4.1.62132"
+ICalendar_VERSION = "4.1.64823"
 
 class ICalendar(BaseEndpoint):
     def __init__(self, apiKey, url ,containerUid ):
@@ -32,6 +32,14 @@ class ICalendar(BaseEndpoint):
         self.containerUid_ = containerUid
         self.base = self.base.replace('{containerUid}',containerUid)
 
+    def getVersion (self):
+        postUri = "/_version";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        return self.handleResult__(serder.LONG, response)
     def filteredChangesetById (self, since , arg1 ):
         postUri = "/_filteredChangesetById";
         __data__ = None
@@ -48,6 +56,163 @@ class ICalendar(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)
+    def itemChangelog (self, uid , arg1 ):
+        postUri = "/{uid}/_itemchangelog";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        __data__ = serder.LONG.encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {    };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
+        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
+        return self.handleResult__(__ItemChangelogSerDer__(), response)
+    def changeset (self, since ):
+        postUri = "/_changeset";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  'since': since   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
+    def changesetById (self, since ):
+        postUri = "/_changesetById";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  'since': since   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
+        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
+        return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
+    def containerChangelog (self, arg0 ):
+        postUri = "/_changelog";
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.LONG.encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
+        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
+        return self.handleResult__(__ContainerChangelogSerDer__(), response)
+    def allIds (self, filter , knownContainerVersion , limit , offset ):
+        postUri = "/_itemIds";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  'filter': filter  , 'knownContainerVersion': knownContainerVersion  , 'limit': limit  , 'offset': offset   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        from netbluemind.core.api.ListResult import ListResult
+        from netbluemind.core.api.ListResult import __ListResultSerDer__
+        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
+    def multipleGetById (self, arg0 ):
+        postUri = "/_mgetById";
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        from netbluemind.calendar.api.VEventSeries import VEventSeries
+        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VEventSeriesSerDer__())), response)
+    def getCompleteById (self, id ):
+        postUri = "/{id}/completeById";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}",id);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        from netbluemind.calendar.api.VEventSeries import VEventSeries
+        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(__ItemValueSerDer__(__VEventSeriesSerDer__()), response)
+    def multipleDeleteById (self, arg0 ):
+        postUri = "/_multipleDelete";
+        __data__ = None
+        __encoded__ = None
+        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
+    def updateById (self, id , arg1 ):
+        postUri = "/id/{id}";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}",id);
+        from netbluemind.calendar.api.VEventSeries import VEventSeries
+        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
+        __data__ = __VEventSeriesSerDer__().encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {    };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        from netbluemind.core.container.api.Ack import Ack
+        from netbluemind.core.container.api.Ack import __AckSerDer__
+        return self.handleResult__(__AckSerDer__(), response)
+    def deleteById (self, id ):
+        postUri = "/id/{id}";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}",id);
+        queryParams = {   };
+
+        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
+    def createById (self, id , arg1 ):
+        postUri = "/id/{id}";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{id}",id);
+        from netbluemind.calendar.api.VEventSeries import VEventSeries
+        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
+        __data__ = __VEventSeriesSerDer__().encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {    };
+
+        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        from netbluemind.core.container.api.Ack import Ack
+        from netbluemind.core.container.api.Ack import __AckSerDer__
+        return self.handleResult__(__AckSerDer__(), response)
+    def count (self, arg0 ):
+        postUri = "/_count";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
+        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
+        __data__ = __ItemFlagFilterSerDer__().encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        from netbluemind.core.container.api.Count import Count
+        from netbluemind.core.container.api.Count import __CountSerDer__
+        return self.handleResult__(__CountSerDer__(), response)
+    def sortedIds (self, arg0 ):
+        postUri = "/_sorted";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
+        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
+        __data__ = __SortDescriptorSerDer__().encode(arg0)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
+        return self.handleResult__(serder.ListSerDer(serder.LONG), response)
     def update (self, uid , event , sendNotifications ):
         postUri = "/{uid}";
         __data__ = None
@@ -84,26 +249,6 @@ class ICalendar(BaseEndpoint):
 
         response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def changeset (self, since ):
-        postUri = "/_changeset";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  'since': since   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
-    def changesetById (self, since ):
-        postUri = "/_changesetById";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  'since': since   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
     def search (self, query ):
         postUri = "/_search";
         __data__ = None
@@ -135,19 +280,6 @@ class ICalendar(BaseEndpoint):
 
         response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def getCompleteById (self, id ):
-        postUri = "/{id}/completeById";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}",id);
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        from netbluemind.calendar.api.VEventSeries import VEventSeries
-        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(__ItemValueSerDer__(__VEventSeriesSerDer__()), response)
     def all (self):
         postUri = "/_all";
         __data__ = None
@@ -156,14 +288,6 @@ class ICalendar(BaseEndpoint):
 
         response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
         return self.handleResult__(serder.ListSerDer(serder.STRING), response)
-    def getVersion (self):
-        postUri = "/_version";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        return self.handleResult__(serder.LONG, response)
     def multipleGet (self, uids ):
         postUri = "/_mget";
         __data__ = None
@@ -178,34 +302,6 @@ class ICalendar(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VEventSeriesSerDer__())), response)
-    def updateWithItem (self, eventItem ):
-        postUri = "/_updateWithItem";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.calendar.api.VEventSeries import VEventSeries
-        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        __data__ = __ItemValueSerDer__(__VEventSeriesSerDer__()).encode(eventItem)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
-    def count (self, arg0 ):
-        postUri = "/_count";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
-        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
-        __data__ = __ItemFlagFilterSerDer__().encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        from netbluemind.core.container.api.Count import Count
-        from netbluemind.core.container.api.Count import __CountSerDer__
-        return self.handleResult__(__CountSerDer__(), response)
     def touch (self, uid ):
         postUri = "/{uid}/_touch";
         __data__ = None
@@ -229,18 +325,6 @@ class ICalendar(BaseEndpoint):
         from netbluemind.core.api.ListResult import ListResult
         from netbluemind.core.api.ListResult import __ListResultSerDer__
         return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__VEventSeriesSerDer__())), response)
-    def sortedIds (self, sorted ):
-        postUri = "/_sorted";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.core.container.model.SortDescriptor import SortDescriptor
-        from netbluemind.core.container.model.SortDescriptor import __SortDescriptorSerDer__
-        __data__ = __SortDescriptorSerDer__().encode(sorted)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        return self.handleResult__(serder.ListSerDer(serder.LONG), response)
     def sync (self, since , changes ):
         postUri = "/_sync";
         __data__ = None
@@ -255,44 +339,6 @@ class ICalendar(BaseEndpoint):
         from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
         from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
         return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
-    def itemChangelog (self, uid , arg1 ):
-        postUri = "/{uid}/_itemchangelog";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        __data__ = serder.LONG.encode(arg1)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {    };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
-        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
-        return self.handleResult__(__ItemChangelogSerDer__(), response)
-    def multipleDeleteById (self, arg0 ):
-        postUri = "/_multipleDelete";
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
-    def updateById (self, id , value ):
-        postUri = "/id/{id}";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}",id);
-        from netbluemind.calendar.api.VEventSeries import VEventSeries
-        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
-        __data__ = __VEventSeriesSerDer__().encode(value)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {    };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        from netbluemind.core.container.api.Ack import Ack
-        from netbluemind.core.container.api.Ack import __AckSerDer__
-        return self.handleResult__(__AckSerDer__(), response)
     def getComplete (self, uid ):
         postUri = "/{uid}/complete";
         __data__ = None
@@ -306,46 +352,6 @@ class ICalendar(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__VEventSeriesSerDer__()), response)
-    def multipleGetById (self, ids ):
-        postUri = "/_mgetById";
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.ListSerDer(serder.LONG).encode(ids)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        from netbluemind.calendar.api.VEventSeries import VEventSeries
-        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VEventSeriesSerDer__())), response)
-    def createWithItem (self, eventItem ):
-        postUri = "/_createWithItem";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.calendar.api.VEventSeries import VEventSeries
-        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        __data__ = __ItemValueSerDer__(__VEventSeriesSerDer__()).encode(eventItem)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
-    def containerChangelog (self, arg0 ):
-        postUri = "/_changelog";
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.LONG.encode(arg0)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
-        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
-        return self.handleResult__(__ContainerChangelogSerDer__(), response)
     def isAutoSyncActivated (self):
         postUri = "/_isAutoSyncActivated";
         __data__ = None
@@ -354,15 +360,6 @@ class ICalendar(BaseEndpoint):
 
         response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
         return self.handleResult__(serder.BOOLEAN, response)
-    def deleteById (self, id ):
-        postUri = "/id/{id}";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}",id);
-        queryParams = {   };
-
-        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
     def searchPendingCounters (self):
         postUri = "/_search_counters";
         __data__ = None
@@ -387,21 +384,6 @@ class ICalendar(BaseEndpoint):
         from netbluemind.core.task.api.TaskRef import TaskRef
         from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
         return self.handleResult__(__TaskRefSerDer__(), response)
-    def createById (self, id , event ):
-        postUri = "/id/{id}";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{id}",id);
-        from netbluemind.calendar.api.VEventSeries import VEventSeries
-        from netbluemind.calendar.api.VEventSeries import __VEventSeriesSerDer__
-        __data__ = __VEventSeriesSerDer__().encode(event)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {    };
-
-        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        from netbluemind.core.container.api.Ack import Ack
-        from netbluemind.core.container.api.Ack import __AckSerDer__
-        return self.handleResult__(__AckSerDer__(), response)
     def getByIcsUid (self, uid ):
         postUri = "/_icsuid/{uid}";
         __data__ = None
@@ -415,13 +397,3 @@ class ICalendar(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__VEventSeriesSerDer__())), response)
-    def allIds (self, filter , knownContainerVersion , limit , offset ):
-        postUri = "/_itemIds";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  'filter': filter  , 'knownContainerVersion': knownContainerVersion  , 'limit': limit  , 'offset': offset   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendar_VERSION}, data = __encoded__);
-        from netbluemind.core.api.ListResult import ListResult
-        from netbluemind.core.api.ListResult import __ListResultSerDer__
-        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)
