@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-ICalendarView_VERSION = "4.1.62132"
+ICalendarView_VERSION = "4.1.64823"
 
 class ICalendarView(BaseEndpoint):
     def __init__(self, apiKey, url ,containerUid ):
@@ -103,16 +103,6 @@ class ICalendarView(BaseEndpoint):
 
         response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendarView_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def changeset (self, since ):
-        postUri = "/_changeset";
-        __data__ = None
-        __encoded__ = None
-        queryParams = {  'since': since   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICalendarView_VERSION}, data = __encoded__);
-        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
-        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
-        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
     def getComplete (self, uid ):
         postUri = "/{uid}";
         __data__ = None
