@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-ITask_VERSION = "4.1.62132"
+ITask_VERSION = "4.1.64823"
 
 class ITask(BaseEndpoint):
     def __init__(self, apiKey, url ,taskId ):
@@ -40,11 +40,11 @@ class ITask(BaseEndpoint):
 
         response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITask_VERSION}, data = __encoded__);
         return response.content
-    def getCurrentLogs (self):
+    def getCurrentLogs (self, offset ):
         postUri = "/_currentLogs";
         __data__ = None
         __encoded__ = None
-        queryParams = {  };
+        queryParams = {  'offset': offset   };
 
         response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITask_VERSION}, data = __encoded__);
         return self.handleResult__(serder.ListSerDer(serder.STRING), response)
