@@ -31,6 +31,7 @@ class DirEntryQuery :
         self.systemFilter = None
         self.kindsFilter = None
         self.entries = None
+        self.orgUnitIds = None
         self.accountTypeFilter = None
         self.from_ = None
         self.size = None
@@ -76,6 +77,8 @@ class __DirEntryQuerySerDer__:
         instance.kindsFilter = serder.ListSerDer(__BaseDirEntryKindSerDer__()).parse(kindsFilterValue)
         entriesValue = value['entries']
         instance.entries = serder.ListSerDer(serder.STRING).parse(entriesValue)
+        orgUnitIdsValue = value['orgUnitIds']
+        instance.orgUnitIds = serder.ListSerDer(serder.LONG).parse(orgUnitIdsValue)
         from netbluemind.directory.api.BaseDirEntryAccountType import BaseDirEntryAccountType
         from netbluemind.directory.api.BaseDirEntryAccountType import __BaseDirEntryAccountTypeSerDer__
         accountTypeFilterValue = value['accountTypeFilter']
@@ -125,6 +128,8 @@ class __DirEntryQuerySerDer__:
         instance["kindsFilter"] = serder.ListSerDer(__BaseDirEntryKindSerDer__()).encode(kindsFilterValue)
         entriesValue = value.entries
         instance["entries"] = serder.ListSerDer(serder.STRING).encode(entriesValue)
+        orgUnitIdsValue = value.orgUnitIds
+        instance["orgUnitIds"] = serder.ListSerDer(serder.LONG).encode(orgUnitIdsValue)
         from netbluemind.directory.api.BaseDirEntryAccountType import BaseDirEntryAccountType
         from netbluemind.directory.api.BaseDirEntryAccountType import __BaseDirEntryAccountTypeSerDer__
         accountTypeFilterValue = value.accountTypeFilter
