@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IDirEntryMaintenance_VERSION = "4.1.62132"
+IDirEntryMaintenance_VERSION = "4.1.64823"
 
 class IDirEntryMaintenance(BaseEndpoint):
     def __init__(self, apiKey, url ,domain ,entryUid ):
@@ -43,24 +43,14 @@ class IDirEntryMaintenance(BaseEndpoint):
         response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirEntryMaintenance_VERSION}, data = __encoded__);
         from netbluemind.directory.api.MaintenanceOperation import MaintenanceOperation
         from netbluemind.directory.api.MaintenanceOperation import __MaintenanceOperationSerDer__
-        return self.handleResult__(serder.SetSerDer(__MaintenanceOperationSerDer__()), response)
-    def repair (self, opIdentifiers ):
+        return self.handleResult__(serder.ListSerDer(__MaintenanceOperationSerDer__()), response)
+    def repair (self, config ):
         postUri = "/_maintenance/repair";
         __data__ = None
         __encoded__ = None
-        __data__ = serder.SetSerDer(serder.STRING).encode(opIdentifiers)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDirEntryMaintenance_VERSION}, data = __encoded__);
-        from netbluemind.core.task.api.TaskRef import TaskRef
-        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
-        return self.handleResult__(__TaskRefSerDer__(), response)
-    def check (self, opIdentifiers ):
-        postUri = "/_maintenance/check";
-        __data__ = None
-        __encoded__ = None
-        __data__ = serder.SetSerDer(serder.STRING).encode(opIdentifiers)
+        from netbluemind.directory.api.RepairConfig import RepairConfig
+        from netbluemind.directory.api.RepairConfig import __RepairConfigSerDer__
+        __data__ = __RepairConfigSerDer__().encode(config)
         __encoded__ = json.dumps(__data__)
         queryParams = {   };
 
