@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IExternalUser_VERSION = "4.1.62132"
+IExternalUser_VERSION = "4.1.64823"
 
 class IExternalUser(BaseEndpoint):
     def __init__(self, apiKey, url ,domainUid ):
@@ -32,6 +32,28 @@ class IExternalUser(BaseEndpoint):
         self.domainUid_ = domainUid
         self.base = self.base.replace('{domainUid}',domainUid)
 
+    def memberOf (self, uid ):
+        postUri = "/{uid}/groups";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalUser_VERSION}, data = __encoded__);
+        from netbluemind.group.api.Group import Group
+        from netbluemind.group.api.Group import __GroupSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
+    def memberOfGroups (self, uid ):
+        postUri = "/{uid}/groupUids";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalUser_VERSION}, data = __encoded__);
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
     def byExtId (self, extid ):
         postUri = "/byExtId/{extid}";
         __data__ = None
@@ -45,20 +67,6 @@ class IExternalUser(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__ExternalUserSerDer__()), response)
-    def updateWithItem (self, externalUserItem ):
-        postUri = "/_updateWithItem";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.externaluser.api.ExternalUser import ExternalUser
-        from netbluemind.externaluser.api.ExternalUser import __ExternalUserSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        __data__ = __ItemValueSerDer__(__ExternalUserSerDer__()).encode(externalUserItem)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalUser_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
     def update (self, uid , externalUser ):
         postUri = "/{uid}";
         __data__ = None
@@ -94,20 +102,6 @@ class IExternalUser(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__ExternalUserSerDer__()), response)
-    def createWithItem (self, externalUserItem ):
-        postUri = "/_createWithItem";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.externaluser.api.ExternalUser import ExternalUser
-        from netbluemind.externaluser.api.ExternalUser import __ExternalUserSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        __data__ = __ItemValueSerDer__(__ExternalUserSerDer__()).encode(externalUserItem)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalUser_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
     def create (self, uid , externalUser ):
         postUri = "/{uid}";
         __data__ = None
@@ -121,28 +115,6 @@ class IExternalUser(BaseEndpoint):
 
         response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalUser_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def memberOf (self, uid ):
-        postUri = "/{uid}/groups";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalUser_VERSION}, data = __encoded__);
-        from netbluemind.group.api.Group import Group
-        from netbluemind.group.api.Group import __GroupSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
-    def memberOfGroups (self, uid ):
-        postUri = "/{uid}/groupUids";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalUser_VERSION}, data = __encoded__);
-        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
     def createWithExtId (self, uid , extid , externalUser ):
         postUri = "/{uid}/{extid}/createwithextid";
         __data__ = None
