@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IGroup_VERSION = "4.1.62132"
+IGroup_VERSION = "4.1.64823"
 
 class IGroup(BaseEndpoint):
     def __init__(self, apiKey, url ,domainUid ):
@@ -32,6 +32,39 @@ class IGroup(BaseEndpoint):
         self.domainUid_ = domainUid
         self.base = self.base.replace('{domainUid}',domainUid)
 
+    def setExtId (self, uid , arg1 ):
+        postUri = "/{uid}/_extId";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        __data__ = serder.STRING.encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {    };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
+    def memberOf (self, uid ):
+        postUri = "/{uid}/groups";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
+        from netbluemind.group.api.Group import Group
+        from netbluemind.group.api.Group import __GroupSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
+    def memberOfGroups (self, uid ):
+        postUri = "/{uid}/groupUids";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
     def getExpandedUserMembers (self, uid ):
         postUri = "/{uid}/expandedusersmembers";
         __data__ = None
@@ -167,28 +200,6 @@ class IGroup(BaseEndpoint):
 
         response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def memberOf (self, uid ):
-        postUri = "/{uid}/groups";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
-        from netbluemind.group.api.Group import Group
-        from netbluemind.group.api.Group import __GroupSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
-    def memberOfGroups (self, uid ):
-        postUri = "/{uid}/groupUids";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
-        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
     def setRoles (self, uid , roles ):
         postUri = "/{uid}/roles";
         __data__ = None
@@ -235,20 +246,6 @@ class IGroup(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
-    def updateWithItem (self, groupItem ):
-        postUri = "/_updateWithItem";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.group.api.Group import Group
-        from netbluemind.group.api.Group import __GroupSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        __data__ = __ItemValueSerDer__(__GroupSerDer__()).encode(groupItem)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
     def touch (self, uid ):
         postUri = "/{uid}/_touch";
         __data__ = None
@@ -256,17 +253,6 @@ class IGroup(BaseEndpoint):
         postUri = postUri.replace("{uid}",uid);
         queryParams = {   };
 
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
-    def setExtId (self, uid , arg1 ):
-        postUri = "/{uid}/_extId";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        __data__ = serder.STRING.encode(arg1)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {    };
-
         response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
     def getComplete (self, uid ):
@@ -282,20 +268,6 @@ class IGroup(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__GroupSerDer__()), response)
-    def createWithItem (self, groupItem ):
-        postUri = "/_createWithItem";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.group.api.Group import Group
-        from netbluemind.group.api.Group import __GroupSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        __data__ = __ItemValueSerDer__(__GroupSerDer__()).encode(groupItem)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IGroup_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
     def getGroupsWithRoles (self, roles ):
         postUri = "/_rolegroups";
         __data__ = None
