@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IMailboxMgmt_VERSION = "4.1.62132"
+IMailboxMgmt_VERSION = "4.1.64823"
 
 class IMailboxMgmt(BaseEndpoint):
     def __init__(self, apiKey, url ,domainUid ):
@@ -73,12 +73,23 @@ class IMailboxMgmt(BaseEndpoint):
         from netbluemind.core.task.api.TaskRef import TaskRef
         from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
         return self.handleResult__(__TaskRefSerDer__(), response)
-    def moveIndex (self, mailboxUid , index ):
+    def moveIndex (self, mailboxUid , index , deleteSource ):
         postUri = "/{mailboxUid}/_move_index";
         __data__ = None
         __encoded__ = None
         postUri = postUri.replace("{mailboxUid}",mailboxUid);
-        queryParams = {   'index': index   };
+        queryParams = {   'index': index  , 'deleteSource': deleteSource   };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxMgmt_VERSION}, data = __encoded__);
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
+    def resetMailbox (self, mailboxUid ):
+        postUri = "/{mailboxUid}/_reset";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{mailboxUid}",mailboxUid);
+        queryParams = {   };
 
         response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxMgmt_VERSION}, data = __encoded__);
         from netbluemind.core.task.api.TaskRef import TaskRef
