@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IResources_VERSION = "4.1.62132"
+IResources_VERSION = "4.1.64823"
 
 class IResources(BaseEndpoint):
     def __init__(self, apiKey, url ,domainUid ):
@@ -58,20 +58,6 @@ class IResources(BaseEndpoint):
 
         response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResources_VERSION}, data = __encoded__);
         return self.handleResult__(serder.STRING, response)
-    def updateWithItem (self, resourceDescriptorItem ):
-        postUri = "/_updateWithItem";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.resource.api.ResourceDescriptor import ResourceDescriptor
-        from netbluemind.resource.api.ResourceDescriptor import __ResourceDescriptorSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        __data__ = __ItemValueSerDer__(__ResourceDescriptorSerDer__()).encode(resourceDescriptorItem)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResources_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
     def update (self, uid , resourceDescriptor ):
         postUri = "/{uid}";
         __data__ = None
@@ -116,20 +102,6 @@ class IResources(BaseEndpoint):
 
         response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResources_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def createWithItem (self, resourceDescriptorItem ):
-        postUri = "/_createWithItem";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.resource.api.ResourceDescriptor import ResourceDescriptor
-        from netbluemind.resource.api.ResourceDescriptor import __ResourceDescriptorSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        __data__ = __ItemValueSerDer__(__ResourceDescriptorSerDer__()).encode(resourceDescriptorItem)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResources_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
     def get (self, uid ):
         postUri = "/{uid}";
         __data__ = None
