@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-ICacheMgmt_VERSION = "4.1.62132"
+ICacheMgmt_VERSION = "4.1.64823"
 
 class ICacheMgmt(BaseEndpoint):
     def __init__(self, apiKey, url ):
@@ -30,6 +30,14 @@ class ICacheMgmt(BaseEndpoint):
         self.apiKey = apiKey
         self.base = url +'/system/cache'
 
+    def dumpContent (self):
+        postUri = "/_dump";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICacheMgmt_VERSION}, data = __encoded__);
+        return response.content
     def flushCaches (self):
         postUri = "/_flush";
         __data__ = None
