@@ -25,8 +25,10 @@ class SystemState(Enum):
     CORE_STATE_STARTING = 'CORE_STATE_STARTING';
     CORE_STATE_RUNNING = 'CORE_STATE_RUNNING';
     CORE_STATE_MAINTENANCE = 'CORE_STATE_MAINTENANCE';
+    CORE_STATE_DEMOTED = 'CORE_STATE_DEMOTED';
     CORE_STATE_NOT_INSTALLED = 'CORE_STATE_NOT_INSTALLED';
     CORE_STATE_UPGRADE = 'CORE_STATE_UPGRADE';
+    CORE_STATE_CLONING = 'CORE_STATE_CLONING';
     CORE_STATE_STOPPING = 'CORE_STATE_STOPPING';
     CORE_STATE_UNKNOWN = 'CORE_STATE_UNKNOWN';
 
