@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IHotUpgrade_VERSION = "4.1.62132"
+IHotUpgrade_VERSION = "4.1.64823"
 
 class IHotUpgrade(BaseEndpoint):
     def __init__(self, apiKey, url ):
@@ -30,6 +30,16 @@ class IHotUpgrade(BaseEndpoint):
         self.apiKey = apiKey
         self.base = url +'/hot_upgrade'
 
+    def running (self):
+        postUri = "/running";
+        __data__ = None
+        __encoded__ = None
+        queryParams = {  };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IHotUpgrade_VERSION}, data = __encoded__);
+        from netbluemind.system.api.hot.upgrade.HotUpgradeTask import HotUpgradeTask
+        from netbluemind.system.api.hot.upgrade.HotUpgradeTask import __HotUpgradeTaskSerDer__
+        return self.handleResult__(serder.SetSerDer(__HotUpgradeTaskSerDer__()), response)
     def progress (self):
         postUri = "/progress";
         __data__ = None
