@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IInternalHotUpgrade_VERSION = "4.1.62132"
+IInternalHotUpgrade_VERSION = "4.1.64823"
 
 class IInternalHotUpgrade(BaseEndpoint):
     def __init__(self, apiKey, url ):
@@ -30,35 +30,26 @@ class IInternalHotUpgrade(BaseEndpoint):
         self.apiKey = apiKey
         self.base = url +'/hot_upgrade'
 
-    def startLimited (self, maxDuration , mode ):
-        postUri = "/limitedStart";
+    def running (self):
+        postUri = "/running";
         __data__ = None
         __encoded__ = None
-        postUri = postUri.replace("{maxDuration}",maxDuration);
-        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import HotUpgradeTaskExecutionMode
-        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import __HotUpgradeTaskExecutionModeSerDer__
-        __data__ = __HotUpgradeTaskExecutionModeSerDer__().encode(mode)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {    };
+        queryParams = {  };
 
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInternalHotUpgrade_VERSION}, data = __encoded__);
-        from netbluemind.core.task.api.TaskRef import TaskRef
-        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
-        return self.handleResult__(__TaskRefSerDer__(), response)
-    def start (self, mode ):
-        postUri = "/start";
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInternalHotUpgrade_VERSION}, data = __encoded__);
+        from netbluemind.system.api.hot.upgrade.HotUpgradeTask import HotUpgradeTask
+        from netbluemind.system.api.hot.upgrade.HotUpgradeTask import __HotUpgradeTaskSerDer__
+        return self.handleResult__(serder.SetSerDer(__HotUpgradeTaskSerDer__()), response)
+    def progress (self):
+        postUri = "/progress";
         __data__ = None
         __encoded__ = None
-        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import HotUpgradeTaskExecutionMode
-        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import __HotUpgradeTaskExecutionModeSerDer__
-        __data__ = __HotUpgradeTaskExecutionModeSerDer__().encode(mode)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
+        queryParams = {  };
 
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInternalHotUpgrade_VERSION}, data = __encoded__);
-        from netbluemind.core.task.api.TaskRef import TaskRef
-        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
-        return self.handleResult__(__TaskRefSerDer__(), response)
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInternalHotUpgrade_VERSION}, data = __encoded__);
+        from netbluemind.system.api.hot.upgrade.HotUpgradeProgress import HotUpgradeProgress
+        from netbluemind.system.api.hot.upgrade.HotUpgradeProgress import __HotUpgradeProgressSerDer__
+        return self.handleResult__(serder.ListSerDer(__HotUpgradeProgressSerDer__()), response)
     def list (self, filter ):
         postUri = "/list";
         __data__ = None
@@ -73,13 +64,31 @@ class IInternalHotUpgrade(BaseEndpoint):
         from netbluemind.system.api.hot.upgrade.HotUpgradeTask import HotUpgradeTask
         from netbluemind.system.api.hot.upgrade.HotUpgradeTask import __HotUpgradeTaskSerDer__
         return self.handleResult__(serder.ListSerDer(__HotUpgradeTaskSerDer__()), response)
-    def progress (self):
-        postUri = "/progress";
+    def startLimited (self, maxDuration , mode ):
+        postUri = "/limitedStart";
         __data__ = None
         __encoded__ = None
-        queryParams = {  };
+        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import HotUpgradeTaskExecutionMode
+        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import __HotUpgradeTaskExecutionModeSerDer__
+        __data__ = __HotUpgradeTaskExecutionModeSerDer__().encode(mode)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {  'maxDuration': maxDuration    };
 
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInternalHotUpgrade_VERSION}, data = __encoded__);
-        from netbluemind.system.api.hot.upgrade.HotUpgradeProgress import HotUpgradeProgress
-        from netbluemind.system.api.hot.upgrade.HotUpgradeProgress import __HotUpgradeProgressSerDer__
-        return self.handleResult__(serder.ListSerDer(__HotUpgradeProgressSerDer__()), response)
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInternalHotUpgrade_VERSION}, data = __encoded__);
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
+    def start (self, onlyReady , mode ):
+        postUri = "/start";
+        __data__ = None
+        __encoded__ = None
+        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import HotUpgradeTaskExecutionMode
+        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import __HotUpgradeTaskExecutionModeSerDer__
+        __data__ = __HotUpgradeTaskExecutionModeSerDer__().encode(mode)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {  'onlyReady': onlyReady    };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IInternalHotUpgrade_VERSION}, data = __encoded__);
+        from netbluemind.core.task.api.TaskRef import TaskRef
+        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
+        return self.handleResult__(__TaskRefSerDer__(), response)
