@@ -22,7 +22,7 @@ import json
 from netbluemind.python import serder
 from netbluemind.python.client import BaseEndpoint
 
-IUser_VERSION = "4.1.62132"
+IUser_VERSION = "4.1.64823"
 
 class IUser(BaseEndpoint):
     def __init__(self, apiKey, url ,domainUid ):
@@ -32,6 +32,77 @@ class IUser(BaseEndpoint):
         self.domainUid_ = domainUid
         self.base = self.base.replace('{domainUid}',domainUid)
 
+    def getPhoto (self, uid ):
+        postUri = "/{uid}/photo";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
+        return self.handleResult__(serder.ByteArraySerDer, response)
+    def deletePhoto (self, uid ):
+        postUri = "/{uid}/photo";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        queryParams = {   };
+
+        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
+    def getIcon (self, uid ):
+        postUri = "/{uid}/icon";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
+        return self.handleResult__(serder.ByteArraySerDer, response)
+    def setPhoto (self, uid , arg1 ):
+        postUri = "/{uid}/photo";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        __data__ = serder.ByteArraySerDer.encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {    };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
+    def setExtId (self, uid , arg1 ):
+        postUri = "/{uid}/_extId";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        __data__ = serder.STRING.encode(arg1)
+        __encoded__ = json.dumps(__data__)
+        queryParams = {    };
+
+        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
+        return self.handleResult__(None, response)
+    def memberOf (self, uid ):
+        postUri = "/{uid}/groups";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
+        from netbluemind.group.api.Group import Group
+        from netbluemind.group.api.Group import __GroupSerDer__
+        from netbluemind.core.container.model.ItemValue import ItemValue
+        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
+        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
+    def memberOfGroups (self, uid ):
+        postUri = "/{uid}/groupUids";
+        __data__ = None
+        __encoded__ = None
+        postUri = postUri.replace("{uid}",uid);
+        queryParams = {   };
+
+        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
+        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
     def setPassword (self, uid , password ):
         postUri = "/{uid}/password_";
         __data__ = None
@@ -45,15 +116,6 @@ class IUser(BaseEndpoint):
 
         response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def getPhoto (self, uid ):
-        postUri = "/{uid}/photo";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
-        return self.handleResult__(serder.ByteArraySerDer, response)
     def allUids (self):
         postUri = "/_alluids";
         __data__ = None
@@ -97,15 +159,6 @@ class IUser(BaseEndpoint):
         from netbluemind.core.task.api.TaskRef import TaskRef
         from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
         return self.handleResult__(__TaskRefSerDer__(), response)
-    def deletePhoto (self, uid ):
-        postUri = "/{uid}/photo";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        queryParams = {   };
-
-        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
     def updateAccountType (self, uid , accountType ):
         postUri = "/_updateAccountType/{uid}";
         __data__ = None
@@ -167,28 +220,6 @@ class IUser(BaseEndpoint):
 
         response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
         return self.handleResult__(None, response)
-    def memberOf (self, uid ):
-        postUri = "/{uid}/groups";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
-        from netbluemind.group.api.Group import Group
-        from netbluemind.group.api.Group import __GroupSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)
-    def memberOfGroups (self, uid ):
-        postUri = "/{uid}/groupUids";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
-        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
     def setRoles (self, uid , roles ):
         postUri = "/{uid}/roles";
         __data__ = None
@@ -235,40 +266,6 @@ class IUser(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
-    def updateWithItem (self, userItem ):
-        postUri = "/_updateWithItem";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.user.api.User import User
-        from netbluemind.user.api.User import __UserSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        __data__ = __ItemValueSerDer__(__UserSerDer__()).encode(userItem)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
-    def setExtId (self, uid , arg1 ):
-        postUri = "/{uid}/_extId";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        __data__ = serder.STRING.encode(arg1)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {    };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
-    def getIcon (self, uid ):
-        postUri = "/{uid}/icon";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        queryParams = {   };
-
-        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
-        return self.handleResult__(serder.ByteArraySerDer, response)
     def getComplete (self, uid ):
         postUri = "/{uid}/complete";
         __data__ = None
@@ -282,31 +279,6 @@ class IUser(BaseEndpoint):
         from netbluemind.core.container.model.ItemValue import ItemValue
         from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
         return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)
-    def createWithItem (self, userItem ):
-        postUri = "/_createWithItem";
-        __data__ = None
-        __encoded__ = None
-        from netbluemind.user.api.User import User
-        from netbluemind.user.api.User import __UserSerDer__
-        from netbluemind.core.container.model.ItemValue import ItemValue
-        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
-        __data__ = __ItemValueSerDer__(__UserSerDer__()).encode(userItem)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {   };
-
-        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
-    def setPhoto (self, uid , arg1 ):
-        postUri = "/{uid}/photo";
-        __data__ = None
-        __encoded__ = None
-        postUri = postUri.replace("{uid}",uid);
-        __data__ = serder.ByteArraySerDer.encode(arg1)
-        __encoded__ = json.dumps(__data__)
-        queryParams = {    };
-
-        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IUser_VERSION}, data = __encoded__);
-        return self.handleResult__(None, response)
     def getUsersWithRoles (self, roles ):
         postUri = "/_roleusers";
         __data__ = None
